==> enterprisemodules-ora_config-3.20.0.tar.gz: enterprisemodules-ora_config-3.20.0/lib/puppet/type/ora_object_grant/common_with_grant_permissions.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:common_with_grant_permissions, :array_matching => :all) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Mungers::Upcase
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-DESC
    The permissions on the specified object, granted to the specified user with the option to regrant to an other user.

    This is a required array of rights to grant on the user object combination

        ora_object_grant{ ...:
          common_with_grant_permissions => ['execute', 'select'],
        }

    When this list contains less rights then currently granted, the the extra rights will
    be revoked from the user. If the permissions list contains more rights then currently
    granted in the database, the extra rights will be granted to the user.

    If you want to make sure no rights are granted, you must use an empty array.

        ora_object_grant{ ...:
          common_with_grant_permissions => ['execute', 'select'],
        }

  DESC

  isrequired
  data_type('Optional[Array[String[1]]]')

  to_translate_to_resource do |raw_resource|
    return [] if raw_resource['COMMON'] == 'NO'

    granted = raw_resource['GRA'] == 'YES'
    granted ? raw_resource['PRIVS'].split(';') : []
  end

  def insync?(is)
    is = [] if is.to_s == 'absent' || is.nil?
    is.sort == munged_should.sort
  end

  def change_to_s(_from, _to)
    return_value = []
    return_value << "revoked the #{revoked_rights.join(',')} right(s) with grant option" unless revoked_rights.empty?
    return_value << "granted the #{granted_rights.join(',')} right(s) with grant option" unless granted_rights.empty?
    return_value.join(' and ')
  end

  on_apply do
    revoked_rights.each do |right|
      sql(revoke(right), :sid => resource.sid)
    end
    granted_rights.each do |right|
      sql(grant(right), :sid => resource.sid)
    end
    nil
  end

  private

  def munged_should
    should.to_s == 'absent' || should.nil? ? [] : should
  end

  def current_rights
    # TODO: Check why this needs to be so difficult
    resource.to_resource.to_hash.delete_if { |_key, value| value.to_s == 'absent' }.fetch(:common_with_grant_permissions) { [] }
  end

  def expected_rights
    resource.to_hash.fetch(:common_with_grant_permissions) { [] }
  end

  def revoked_rights
    current_rights - expected_rights
  end

  def granted_rights
    expected_rights - current_rights
  end

  def revoke(right)
    "revoke #{right} on #{resource.object_name} from #{resource.grantee} container=all"
  end

  def grant(rights)
    "grant #{rights} on #{resource.object_name} to #{resource.grantee} with grant option container=all"
  end
end

==> enterprisemodules-ora_config-3.22.2.tar.gz: enterprisemodules-ora_config-3.22.2/lib/puppet/type/ora_object_grant/common_with_grant_permissions.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:common_with_grant_permissions, :array_matching => :all) do
  include EasyType
  include PuppetX::EnterpriseModules::Oracle::Mungers::Upcase
  include PuppetX::EnterpriseModules::Oracle::Access

  desc <<-DESC
    The permissions on the specified object, granted to the specified user with the option to regrant to an other user.

    This is a required array of rights to grant on the user object combination

        ora_object_grant{ ...:
          common_with_grant_permissions => ['execute', 'select'],
        }

    When this list contains less rights then currently granted, the the extra rights will
    be revoked from the user. If the permissions list contains more rights then currently
    granted in the database, the extra rights will be granted to the user.

    If you want to make sure no rights are granted, you must use an empty array.

        ora_object_grant{ ...:
          common_with_grant_permissions => ['execute', 'select'],
        }

  DESC

  isrequired
  data_type('Optional[Array[String[1]]]')

  to_translate_to_resource do |raw_resource|
    return [] if raw_resource['COMMON'] == 'NO'

    granted = raw_resource['GRA'] == 'YES'
    granted ? raw_resource['PRIVS'].split(';') : []
  end

  def insync?(is)
    is = [] if is.to_s == 'absent' || is.nil?
    is.sort == munged_should.sort
  end

  def change_to_s(_from, _to)
    return_value = []
    return_value << "revoked the #{revoked_rights.join(',')} right(s) with grant option" unless revoked_rights.empty?
    return_value << "granted the #{granted_rights.join(',')} right(s) with grant option" unless granted_rights.empty?
    return_value.join(' and ')
  end

  on_apply do
    revoked_rights.each do |right|
      sql(revoke(right), :sid => resource.sid)
    end
    granted_rights.each do |right|
      sql(grant(right), :sid => resource.sid)
    end
    nil
  end

  private

  def munged_should
    should.to_s == 'absent' || should.nil? ? [] : should
  end

  def current_rights
    # TODO: Check why this needs to be so difficult
    resource.to_resource.to_hash.delete_if { |_key, value| value.to_s == 'absent' }.fetch(:common_with_grant_permissions) { [] }
  end

  def expected_rights
    resource.to_hash.fetch(:common_with_grant_permissions) { [] }
  end

  def revoked_rights
    current_rights - expected_rights
  end

  def granted_rights
    expected_rights - current_rights
  end

  def revoke(right)
    "revoke #{right} on #{resource.object_name} from #{resource.grantee} container=all"
  end

  def grant(rights)
    "grant #{rights} on #{resource.object_name} to #{resource.grantee} with grant option container=all"
  end
end
